pub enum ContentType {
Show 17 variants
JS,
PDF,
JSON,
XML,
ZIP,
Urlencode,
ImgGif,
ImgJpeg,
ImgPng,
FormData,
CSS,
CSV,
Html,
Text,
MPEG,
MP4,
WEBM,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.