pub enum Information {
Continue,
SwitchingProtocols,
}Expand description
Information Messages
Variants
Continue
This interim response indicates that the client should continue the request or ignore the response if the request is already finished.
SwitchingProtocols
This code is sent in response to an Upgrade request header from the client and indicates the protocol the server is switching to.