Redirection

Enum Redirection 

pub enum Redirection {
    MultipleChoices,
    MovedPermantely,
    Found,
    SeeOther,
    NotModified,
    TemporalyRedirect,
    PermanetRedirect,
}
Redirect

Variants



MultipleChoices

The request has more than one possible response. The user agent or user should choose one of them. (There is no standardized way of choosing one of the responses, but HTML links to the possibilities are recommended so the user can pick.)



MovedPermantely

The URL of the requested resource has been changed permanently. The new URL is given in the response.



Found

This response code means that the URI of requested resource has been changed temporarily. Further changes in the URI might be made in the future. Therefore, this same URI should be used by the client in future requests.



SeeOther

The server sent this response to direct the client to get the requested resource at another URI with a GET request.



NotModified

This is used for caching purposes. It tells the client that the response has not been modified, so the client can continue to use the same cached version of the response.



TemporalyRedirect

The server sends this response to direct the client to get the requested resource at another URI with same method that was used in the prior request. This has the same semantics as the 302 Found HTTP response code, with the exception that the user agent must not change the HTTP method used: if a POST was used in the first request, a POST must be used in the second request.



PermanetRedirect

This means that the resource is now permanently located at another URI, specified by the Location: HTTP Response header. This has the same semantics as the 301 Moved Permanently HTTP response code, with the exception that the user agent must not change the HTTP method used: if a POST was used in the first request, a POST must be used in the second request.