ServerError

Enum ServerError 

pub enum ServerError {
    InternalServerError,
    NotImplemented,
    BadGateway,
    GatewayTimeout,
}
Server Error Messages

Variants



InternalServerError

The server has encountered a situation it does not know how to handle.



NotImplemented

The request method is not supported by the server and cannot be handled. The only methods that servers are required to support (and therefore that must not return this code) are GET and HEAD.



BadGateway

This error response means that the server, while working as a gateway to get a response needed to handle the request, got an invalid response.



GatewayTimeout

This error response is given when the server is acting as a gateway and cannot get a response in time.