pub enum Successfull {
OK,
Created,
Accepted,
PartialContent,
}Expand description
Successfull Messages
Variants
OK
The request succeeded. The result meaning of “success” depends on the HTTP method:
-
GET: The resource has been fetched and transmitted in the message body.
-
HEAD: The representation headers are included in the response without any message body.
-
PUT or POST: The resource describing the result of the action is transmitted in the message body.
-
TRACE: The message body contains the request message as received by the server.
Created
The request succeeded, and a new resource was created as a result. This is typically the response sent after POST requests, or some PUT requests.
Accepted
The request has been received but not yet acted upon. It is noncommittal, since there is no way in HTTP to later send an asynchronous response indicating the outcome of the request. It is intended for cases where another process or server handles the request, or for batch processing.
PartialContent
This response code is used when the Range header is sent from the client to request only part of a resource.